#!/bin/bash
set -euo pipefail

# Get script directory - handle different execution contexts
if [ -n "${BASH_SOURCE[0]}" ]; then
    SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )"
else
    SCRIPT_DIR="$( cd "$( dirname "$0" )" &> /dev/null && pwd )"
fi
PROJECT="$(basename "$(dirname "${SCRIPT_DIR}")")"


# Debug output for CI
echo "${PROJECT} build script running from: ${SCRIPT_DIR}"

mkdir -p "${SCRIPT_DIR}/build"
mkdir -p "${SCRIPT_DIR}/output"

# Run build in container with mounted directories
COMMAND_TO_RUN="cmake -G Ninja -S . -B ./build \
                -DCMAKE_BUILD_TYPE=\${CMAKE_BUILD_TYPE} \
                -DPROJECT_NAME=${PROJECT} && \
                cmake --build ./build && \
                cp ./build/${PROJECT} ./output/"

if [ -n "${GITEA_CONTAINER_NAME:-}" ]; then
  echo "We're in a gitea container: ${GITEA_CONTAINER_NAME}"
  cd "${SCRIPT_DIR}" && ls -la . && ${COMMAND_TO_RUN}
else
  echo "Building in new docker container"
  docker run --rm \
    --user "$(id -u):$(id -g)" \
    -v "${SCRIPT_DIR}:/app:ro" \
    -v "${SCRIPT_DIR}/build:/app/build" \
    -v "${SCRIPT_DIR}/output:/app/output" \
    -e CMAKE_BUILD_TYPE="${CMAKE_BUILD_TYPE:-Debug}" \
    gitea.jde.nz/public/dropshell-build-base:latest \
    bash -c "cd /app && ${COMMAND_TO_RUN}"
fi

echo "Build complete"